bff.cache


CacheStorecljprotocol

cache-getclj

(cache-get this key)

cache-invalidateclj

(cache-invalidate this key)

cache-putclj

(cache-put this key value ttl-ms)
source

invalidateclj

(invalidate store key)

Remove key from store. No-op when store is nil. Never throws.

Remove `key` from `store`. No-op when `store` is nil. Never throws.
sourceraw docstring

lookupclj

(lookup store key)

Return the cached value for key from store, or nil if absent, expired, or if store is nil. Never throws — exceptions are logged and swallowed.

Return the cached value for `key` from `store`, or nil if absent, expired,
or if `store` is nil. Never throws — exceptions are logged and swallowed.
sourceraw docstring

saveclj

(save store key value ttl-ms)

Cache value under key in store with ttl-ms time-to-live. No-op when store is nil. Never throws.

Cache `value` under `key` in `store` with `ttl-ms` time-to-live. No-op
when `store` is nil. Never throws.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries