bff.examples.validators.orders

Example custom validator wired into the demo spec by key.

Example custom validator wired into the demo spec by key.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries