SDL emitter for the intermediate schema map from bff.schema-builder.
SDL emitter for the intermediate schema map from bff.schema-builder.
(emit-sdl {:keys [scalars objects input-objects queries mutations]})Return SDL text for a schema map.
Return SDL text for a schema map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |