bff.executor


BffResolvercljprotocol

resolve-endpointclj

(resolve-endpoint this args ctx)
source

BffTransformercljprotocol

transformclj

(transform this args chain-ctx mapped)
source

execute-graphclj

(execute-graph chain args request-ctx extensions)

Execute the full backend_chain according to dependency waves. Returns a task that resolves to the final chain-ctx map.

extensions is the caller-owned map with :cache and :retry-hooks.

Execute the full backend_chain according to dependency waves.
Returns a task that resolves to the final chain-ctx map.

`extensions` is the caller-owned map with :cache and :retry-hooks.
sourceraw docstring

run-endpointclj

(run-endpoint endpoint args request-ctx extensions)

Build and execute the full endpoint pipeline.

Returns a missionary task resolving to: {:data {...} ; the mapped output fields :errors [{...}] ; any step errors (may be empty)}

extensions is the caller-owned config map. Keys (all optional): :enrichers — ordered seq of context enrichers :validators — {"key" impl} for :validator {:key ...} refs :transformers — {"key" impl} :resolvers — {"key" impl} :retry-hooks — {"key" impl} :cache — a CacheStore, or nil

If the endpoint has a :resolver key, it is called instead of the backend_chain. Partial failures are represented in :errors while :data contains whatever fields could be resolved from successful steps.

Build and execute the full endpoint pipeline.

Returns a missionary task resolving to:
  {:data   {...}         ; the mapped output fields
   :errors [{...}]       ; any step errors (may be empty)}

`extensions` is the caller-owned config map. Keys (all optional):
  :enrichers    — ordered seq of context enrichers
  :validators   — {"key" impl} for :validator {:key ...} refs
  :transformers — {"key" impl}
  :resolvers    — {"key" impl}
  :retry-hooks  — {"key" impl}
  :cache        — a CacheStore, or nil

If the endpoint has a :resolver key, it is called instead of the
backend_chain. Partial failures are represented in :errors while :data
contains whatever fields could be resolved from successful steps.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries