bff.validator


BffValidatorcljprotocol

validateclj

(validate this args ctx)
source

register-validator!clj

(register-validator! k validator)

Register a BffValidator (or plain fn) under key k.

Register a BffValidator (or plain fn) under key k.
sourceraw docstring

run-validationclj

(run-validation endpoint args ctx)

Run all declared validators for an endpoint against the provided args. Returns a seq of {:message ...} error maps, or nil if everything passes. Runs built-in arg rules first, then the custom validator if declared.

Run all declared validators for an endpoint against the provided args.
Returns a seq of {:message ...} error maps, or nil if everything passes.
Runs built-in arg rules first, then the custom validator if declared.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries